==> darwin-shared-0.2.37.tar.gz: darwin-shared-0.2.37/darwin/gateways/auth.py <==
from ..utils.error import errorBreakApi
from ..utils.microservices import Microservice
from ..utils.request import Request, GET
from ..utils.exceptions import MsAuthException
from .kms import KmsGateway


class AuthGateway:

    @classmethod
    def getPublicKey(cls, language, workspaceId=None, memberId=None):
        query = ""
        if workspaceId:
            query = "workspaceId={workspaceId}".format(workspaceId=workspaceId)
        if memberId:
            query = "memberId={memberId}".format(memberId=memberId)

        response = Request.fetch(
            url="{baseUrl}/auth/public-key?{query}".format(baseUrl=Microservice.getBaseUrl(Microservice.auth), query=query),
            method=GET,
            deadline=50
        )

        if response.status == 400:
            return None, response.contentJson()
        elif response.status > 200:
            return None, errorBreakApi(language=language)

        return response.contentJson().get("publicKey"), None

    @classmethod
    def getPrivateKey(cls, language):
        response = Request.fetch(
            url="{baseUrl}/auth/private-key".format(baseUrl=Microservice.getBaseUrl(Microservice.auth)),
            method=GET,
            deadline=50
        )

        if response.status == 400:
            return None, response.contentJson()
        elif response.status > 200:
            return None, errorBreakApi(language=language)

        return response.contentJson().get("privateKey"), None

    @classmethod
    def getExternalCredentials(cls, credentialsId):
        response = Request.fetch(
            url="{baseUrl}/auth/external-credentials/{externalCredentialsId}".format(
                baseUrl=Microservice.getBaseUrl(Microservice.auth),
                externalCredentialsId=credentialsId,
            )
        )

        if response.status == 400:
            raise MsAuthException(response.contentJson())
        if response.status != 200:
            raise MsAuthException(response.content)

        body = response.contentJson()
        encryptedCredentials = body["encryptedData"]
        keyId = body["keyId"]

        rawCredentials = KmsGateway.decrypt(encryptedCredentials, keyId)
        return rawCredentials

==> darwin-shared-v2-0.3.0.tar.gz: darwin-shared-v2-0.3.0/darwin/gateways/auth.py <==
from ..utils.microservices import Microservice
from ..utils.exceptions import MsAuthException
from ..utils.request import Request, GET
from ..utils.error import errorBreakApi
from .kms import KmsGateway
from json import loads


class AuthGateway:

    @classmethod
    def getPrivateKey(cls, language):
        response = Request.fetch(
            url="{baseUrl}/private-key".format(baseUrl=Microservice.getBaseUrl(Microservice.auth)),
            method=GET,
            deadline=50
        )

        if response.status == 400:
            return None, response.contentJson()
        elif response.status > 200:
            return None, errorBreakApi(language=language)

        return response.contentJson().get("privateKey"), None

    @classmethod
    def getExternalCredentials(cls, credentialsId):
        response = Request.fetch(
            url="{baseUrl}/external-credentials/{externalCredentialsId}".format(
                baseUrl=Microservice.getBaseUrl(Microservice.auth),
                externalCredentialsId=credentialsId,
            )
        )

        if response.status == 400:
            raise MsAuthException(response.contentJson())
        if response.status != 200:
            raise MsAuthException(response.content)

        body = response.contentJson()
        encryptedCredentials = body["encryptedData"]
        keyId = body["keyId"]

        rawCredentials = KmsGateway.decrypt(encryptedCredentials, keyId)
        return rawCredentials

    @classmethod
    def getJsonCredentials(cls, credentialsId):
        return loads(cls.getExternalCredentials(credentialsId))
